register

Function register 

pub fn register(registry: &mut Registry) -> Result<(), Box<dyn Transformer>>
Registers all standard Transformers into the provided Registry.

This inserts the default transformers from the string, iter, structure, and state modules.

Errors

Returns an error if a transformer with the same name is already in the Registry. If this happens, any transformers that were successfully registered before the error will remain in the registry.