pub struct Concatenate;Expand description
A transformer that concatenates all elegible input tokens into a single identifier.
It ignores standard spacing and simply glues the string representations of the tokens together.
By “token”, this implies identifier and string literals (not including byte literals, c-strings, or other string type).
This performs a rolling approach, physically contiguous tokens of the same type will be concatenated into one of the same token type.
Example
[< hello _ world "what" "ever" . "buddy" >]:concatenate -> hello_world "whatever" . "buddy"