register

Function register 

pub fn register(registry: &mut Registry) -> Result<(), Box<dyn Transformer>>
Inserts all structure-related Transformers into the specified Registry.

Errors

This will fail if at least one standard structure-related Transformer is already present by-name in the Registry.

On failure, there is no guarantee that other non-colliding transformers have not been registered.