String and text-manipulation Tokel Transformers.
Structs
- Case
- A transformer that changes the case of incoming identifiers, as instructed.
- Concatenate
- A transformer that concatenates all input tokens into a single identifier.
Functions
- register
- Inserts all
string-relatedTransformers into the specifiedRegistry.